@@ -1,18 +1,14 @@
-#!/usr/local/bin/python3.7
+#!/usr/local/bin/python3.12
 
-from __future__ import print_function
-from pathlib import Path
 import logging.handlers
 import sys
-import os
-import site
 if sys.version_info.major < 3:
     print("RouterSploit supports only Python3. Rerun application in Python3 environment.")
     exit(0)
 
 from routersploit.interpreter import RoutersploitInterpreter
 
-log_handler = logging.handlers.RotatingFileHandler(filename=str(Path.home()) + "/routersploit.log", maxBytes=500000)
+log_handler = logging.handlers.RotatingFileHandler(filename="routersploit.log", maxBytes=500000)
 log_formatter = logging.Formatter("%(asctime)s %(levelname)s %(name)s       %(message)s")
 log_handler.setFormatter(log_formatter)
 LOGGER = logging.getLogger()
@@ -20,11 +16,15 @@ LOGGER.setLevel(logging.DEBUG)
 LOGGER.addHandler(log_handler)
 
 
-def routersploit():
+def routersploit(argv):
     rsf = RoutersploitInterpreter()
-    rsf.start()
-
+    if len(argv[1:]):
+        rsf.nonInteractive(argv)
+    else:
+        rsf.start()
 
 if __name__ == "__main__":
-    os.chdir(site.getsitepackages()[0])
-    routersploit()
+    try:
+        routersploit(sys.argv)
+    except (KeyboardInterrupt, SystemExit):
+        pass
